pub struct EncodeSectorOptions<'a, RE>where
RE: RecordsEncoder,{
pub sector_index: SectorIndex,
pub records_encoder: &'a mut RE,
pub abort_early: &'a AtomicBool,
}Expand description
Options for encoding a sector.
Sector output and sector metadata output should be either empty (in which case they’ll be resized to correct size automatically) or correctly sized from the beginning or else error will be returned.
Fields
sector_index: SectorIndexSector index
records_encoder: &'a mut RERecords encoding instance
abort_early: &'a AtomicBoolWhether encoding should be aborted early